@@ -209,7 +209,7 @@ func scanRun(opts *pkg.ScanOptions) error {
 		logrus.Trace("Exited")
 	}()
 
-	scanner := pkg.NewScanner(supplierLibrary.Suppliers(), remoteLibrary, alerter, pkg.ScannerOptions{Deep: opts.Deep})
+	scanner := remote.NewScanner(supplierLibrary.Suppliers(), remoteLibrary, alerter, remote.ScannerOptions{Deep: opts.Deep})
 
 	iacSupplier, err := supplier.GetIACSupplier(opts.From, providerLibrary, opts.BackendOptions, iacProgress, resFactory)
 	if err != nil {
@@ -387,6 +387,20 @@ func parseOutputFlag(out string) (*output.OutputConfig, error) {
 			)
 		}
 		options["path"] = opts[0]
+	case output.PlanOutputType:
+		if len(opts) != 1 || opts[0] == "" {
+			return nil, errors.Wrapf(
+				cmderrors.NewUsageError(
+					fmt.Sprintf(
+						"\nMust be of kind: %s",
+						output.Example(output.PlanOutputType),
+					),
+				),
+				"Invalid plan output '%s'",
+				out,
+			)
+		}
+		options["path"] = opts[0]
 	}
 
 	return &output.OutputConfig{
