@@ -1605,6 +1605,85 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 				result.AssertManagedCount(5)
 			},
 		},
+		{
+			name: "test aws eip association expander middleware",
+			stateResources: []resource.Resource{
+				&resource.AbstractResource{
+					Id:    "ID",
+					Type:  "ANOTHERTYPE",
+					Attrs: &resource.Attributes{},
+				},
+				&resource.AbstractResource{
+					Id:    "associdpresentinstate",
+					Type:  aws.AwsEipAssociationResourceType,
+					Attrs: &resource.Attributes{},
+				},
+				&resource.AbstractResource{
+					Id:   "associdpresentinstate",
+					Type: aws.AwsEipResourceType,
+					Attrs: &resource.Attributes{
+						"association_id": "associdpresentinstate",
+					},
+				},
+				&resource.AbstractResource{
+					Id:   "associdNOTpresentinstate",
+					Type: aws.AwsEipResourceType,
+					Attrs: &resource.Attributes{
+						"association_id":    "associdNOTpresentinstate",
+						"instance":          "instanceidNOTpresentinstate",
+						"network_interface": "networkinterface",
+						"private_ip":        "privateip",
+						"public_ip":         "publicip",
+					},
+				},
+			},
+			remoteResources: []resource.Resource{
+				&resource.AbstractResource{
+					Id:    "ID",
+					Type:  "ANOTHERTYPE",
+					Attrs: &resource.Attributes{},
+				},
+				&resource.AbstractResource{
+					Id:    "associdpresentinstate",
+					Type:  aws.AwsEipAssociationResourceType,
+					Attrs: &resource.Attributes{},
+				},
+				&resource.AbstractResource{
+					Id:   "associdpresentinstate",
+					Type: aws.AwsEipResourceType,
+					Attrs: &resource.Attributes{
+						"association_id": "associdpresentinstate",
+					},
+				},
+				&resource.AbstractResource{
+					Id:   "associdNOTpresentinstate",
+					Type: aws.AwsEipAssociationResourceType,
+					Attrs: &resource.Attributes{
+						"allocation_id":        "associdNOTpresentinstate",
+						"id":                   "associdNOTpresentinstate",
+						"instance_id":          "instanceidNOTpresentinstate",
+						"network_interface_id": "networkinterface",
+						"private_ip_address":   "privateip",
+						"public_ip":            "publicip",
+					},
+				},
+				&resource.AbstractResource{
+					Id:   "associdNOTpresentinstate",
+					Type: aws.AwsEipResourceType,
+					Attrs: &resource.Attributes{
+						"association_id":    "associdNOTpresentinstate",
+						"instance":          "instanceidNOTpresentinstate",
+						"network_interface": "networkinterface",
+						"private_ip":        "privateip",
+						"public_ip":         "publicip",
+					},
+				},
+			},
+			assert: func(result *test.ScanResult, err error) {
+				result.AssertInfrastructureIsInSync()
+				result.AssertManagedCount(5)
+			},
+		},
 	}
 
 	runTest(t, cases)
