@@ -44,11 +44,20 @@ func Init(version string, alerter *alerter.Alerter,
 	deserializer := resource.NewDeserializer(factory)
 	providerLibrary.AddProvider(terraform.GITHUB, provider)
 
-	supplierLibrary.AddSupplier(NewGithubRepositorySupplier(provider, repository, deserializer))
-	supplierLibrary.AddSupplier(NewGithubTeamSupplier(provider, repository, deserializer))
-	supplierLibrary.AddSupplier(NewGithubMembershipSupplier(provider, repository, deserializer))
-	supplierLibrary.AddSupplier(NewGithubTeamMembershipSupplier(provider, repository, deserializer))
-	supplierLibrary.AddSupplier(NewGithubBranchProtectionSupplier(provider, repository, deserializer))
+	remoteLibrary.AddEnumerator(NewGithubTeamEnumerator(repository, factory))
+	remoteLibrary.AddDetailsFetcher(github.GithubTeamResourceType, common.NewGenericDetailsFetcher(github.GithubTeamResourceType, provider, deserializer))
+
+	remoteLibrary.AddEnumerator(NewGithubRepositoryEnumerator(repository, factory))
+	remoteLibrary.AddDetailsFetcher(github.GithubRepositoryResourceType, common.NewGenericDetailsFetcher(github.GithubRepositoryResourceType, provider, deserializer))
+
+	remoteLibrary.AddEnumerator(NewGithubMembershipEnumerator(repository, factory))
+	remoteLibrary.AddDetailsFetcher(github.GithubMembershipResourceType, common.NewGenericDetailsFetcher(github.GithubMembershipResourceType, provider, deserializer))
+
+	remoteLibrary.AddEnumerator(NewGithubTeamMembershipEnumerator(repository, factory))
+	remoteLibrary.AddDetailsFetcher(github.GithubTeamMembershipResourceType, common.NewGenericDetailsFetcher(github.GithubTeamMembershipResourceType, provider, deserializer))
+
+	remoteLibrary.AddEnumerator(NewGithubBranchProtectionEnumerator(repository, factory))
+	remoteLibrary.AddDetailsFetcher(github.GithubBranchProtectionResourceType, common.NewGenericDetailsFetcher(github.GithubBranchProtectionResourceType, provider, deserializer))
 
 	err = resourceSchemaRepository.Init(version, provider.Schema())
 	if err != nil {
