@@ -7,10 +7,11 @@ import (
 	"github.com/cloudskiff/driftctl/test/acceptance"
 )
 
-func TestAcc_AwsDbInstance(t *testing.T) {
+func TestAcc_Aws_DbInstance(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
-		Paths: []string{"./testdata/acc/aws_db_instance"},
-		Args:  []string{"scan", "--filter", "Type=='aws_db_instance'"},
+		TerraformVersion: "0.14.9",
+		Paths:            []string{"./testdata/acc/aws_db_instance"},
+		Args:             []string{"scan", "--filter", "Type=='aws_db_instance'"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
