@@ -9,8 +9,9 @@ import (
 
 func TestAcc_AwsSecurityGroup(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
-		Paths: []string{"./testdata/acc/aws_security_group"},
-		Args:  []string{"scan", "--filter", "Type=='aws_security_group' || Type=='aws_default_security_group'"},
+		TerraformVersion: "0.14.9",
+		Paths:            []string{"./testdata/acc/aws_security_group"},
+		Args:             []string{"scan", "--filter", "Type=='aws_security_group' || Type=='aws_default_security_group'"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -21,7 +22,7 @@ func TestAcc_AwsSecurityGroup(t *testing.T) {
 						t.Fatal(err)
 					}
 					result.AssertInfrastructureIsInSync()
-					result.Equal(2, result.Summary().TotalManaged)
+					result.AssertManagedCount(10)
 				},
 			},
 		},
